OiRA

Help

1. Preparação
2. Envolvimento
3. Identificação + Avaliação
4. Plano de Ação
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Atenção
5. Relatório
6. Estado 9%

# Commercial guarding, Leicester

Após a avaliação dos riscos, é necessário criar um plano de ação para gerir os riscos. Para eliminar ou reduzir os riscos, necessita determinar que medidas de prevenção ou de proteção devem ser tomadas.

Eis alguns aspetos que devem ser considerados nesta fase:

1. O risco pode ser evitado? Pode ser totalmente eliminado? Isto pode ser conseguido, por exemplo, através de:
   - Avaliando se a tarefa é mesmo necessária
   - Removendo totalmente o perigo da tarefa
2. Se alguns riscos não são de todo evitáveis, como poderemos reduzir estes riscos para que não comprometam a saúde e a segurança dos trabalhadores?

Após ter decidido como eliminar ou reduzir um determinado risco, deve descrever as ações específicas que são requeridas. Deve também mencionar o nível de competência e os requisitos necessários para que tais ações sejam eficazes.

Criar plano de ação

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More